@@ -1,11 +1,11 @@
-__version__ = "0.2.3"
+__version__ = "0.3.0"
 __doc__ = """GEMAct is an **actuarial package**, 
 based on the collective risk theory framework, 
 that offers actuarial scientists a comprehensive set of tools for 
 **non-life** (re)insurance **pricing**, stochastic **claims reserving**, 
 **risk aggregation** and extends the set of probability distributions already available in Python. \n
 The broad and flexible GEMAct apparatus fits into the expanding community of **Python** programming language. \n
-Please visit our [website](https://gem-analytics.github.io/gemact/) to see our documentation and tutorial."""
+Please visit our [website](https://gem-analytics.github.io/gemact/) to see our documentation and tutorials."""
 
 import gemact.helperfunctions as hf
 import gemact.distributions as distributions
